# Pentanediol, C5H12O2

## Isomers

- 1,5-Pentanediol - most common isomer
- 2,4-Pentanediol
- 1,2-Pentanediol

## Chemical formula

1,5-Pentanediol: HOCH2CH2CH2CH2CH2OH

## Other names

1,5-Pentanediol:

- Pentane-1,5-diol
- Pentylene glycol
- Pentamethylene glycol
- 1,5-Dihydroxypentane

## External links

- 1,5-Pentanediol - Wikipedia
- 1,5-Pentanediol - NIST Chemistry WebBook
- 2,4-Pentanediol - NIST Chemistry WebBook
- 1,2-Pentanediol - NIST Chemistry WebBook